==> apache-arrow-16.1.0_2.arm64_ventura.bottle.tar.gz: apache-arrow/16.1.0_2/lib/cmake/Parquet/ParquetTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "RELEASE".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "Parquet::parquet_shared" for configuration "RELEASE"
set_property(TARGET Parquet::parquet_shared APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Parquet::parquet_shared PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "thrift::thrift"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libparquet.1601.0.0.dylib"
  IMPORTED_SONAME_RELEASE "@@HOMEBREW_CELLAR@@/apache-arrow/16.1.0_2/lib/libparquet.1601.dylib"
  )

list(APPEND _cmake_import_check_targets Parquet::parquet_shared )
list(APPEND _cmake_import_check_files_for_Parquet::parquet_shared "${_IMPORT_PREFIX}/lib/libparquet.1601.0.0.dylib" )

# Import target "Parquet::parquet_static" for configuration "RELEASE"
set_property(TARGET Parquet::parquet_static APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Parquet::parquet_static PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libparquet.a"
  )

list(APPEND _cmake_import_check_targets Parquet::parquet_static )
list(APPEND _cmake_import_check_files_for_Parquet::parquet_static "${_IMPORT_PREFIX}/lib/libparquet.a" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> apache-arrow-18.0.0.arm64_ventura.bottle.tar.gz: apache-arrow/18.0.0/lib/cmake/Parquet/ParquetTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "RELEASE".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "Parquet::parquet_shared" for configuration "RELEASE"
set_property(TARGET Parquet::parquet_shared APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Parquet::parquet_shared PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "thrift::thrift"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libparquet.1800.0.0.dylib"
  IMPORTED_SONAME_RELEASE "@@HOMEBREW_CELLAR@@/apache-arrow/18.0.0/lib/libparquet.1800.dylib"
  )

list(APPEND _cmake_import_check_targets Parquet::parquet_shared )
list(APPEND _cmake_import_check_files_for_Parquet::parquet_shared "${_IMPORT_PREFIX}/lib/libparquet.1800.0.0.dylib" )

# Import target "Parquet::parquet_static" for configuration "RELEASE"
set_property(TARGET Parquet::parquet_static APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Parquet::parquet_static PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libparquet.a"
  )

list(APPEND _cmake_import_check_targets Parquet::parquet_static )
list(APPEND _cmake_import_check_files_for_Parquet::parquet_static "${_IMPORT_PREFIX}/lib/libparquet.a" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
